/***************************************************************************
 *   copyright       : (C) 2012-2014 by Pascal Brachet                     *
 *   http://www.xm1math.net/pdfadd/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 * Parts of this file come from the documentation of Qt. It was originally *
 * published as part of Qt Quarterly.                                      *
 *                                                                         *
 ***************************************************************************/

#ifndef PDFVIEWER_H
#define PDFVIEWER_H

#include <QtGui>
#include <QMainWindow>
#include <QDockWidget>
#include <QScrollArea>
#include <QComboBox>
#include <QLineEdit>
#include <QPushButton>
#include <QAction>
#include <QProcess>
#include <QPointer>
#include <QKeyEvent>
#include <QPainterPath>
#include <QFrame>
#include <QHBoxLayout>
#include <QMutex>
#include <QStackedWidget>
#include <QToolBar>
#include "pdfdocumentwidget.h"
#include "pdfscrollarea.h"

class PdfViewer : public QMainWindow
{
    Q_OBJECT
public:
    PdfViewer( const QString fileName, const QString externalCommand,QWidget* parent = 0);
    ~PdfViewer();
    QString pdf_file;
public slots:
void openFile(QString fn, QString ec);
private:
void closeEvent(QCloseEvent *e);
QHBoxLayout *CentralLayout;
QByteArray windowstate;
QList<PdfDocumentWidget*> listPdfWidgets, templist;
Poppler::Document *doc;
QAction *fitWithAct, *fitPageAct, *zoominAct, *zoomoutAct, *externAct;
PdfScrollArea  *scrollArea;
QList<int> listPdfWidgetsPos;
QList<int> listPdfWidgetsStatus;
QComboBox *scaleComboBox;
QString viewpdf_command;
int currentPage;
qreal currentScale, lastScale, previousScale;
bool fileLoaded;
QPointer<QProcess> proc;
QString lastFile;
int lastPage, altern;
QStringList scalePercents;
QLineEdit *zoomCustom;
QRectF searchLocation;
QMutex pageMutex;
bool canDisplayPixmap;
int scrollMax, deltaMax;
QPainterPath path;



private slots:
void connectActions();
void disconnectActions();
void setScrollMax();
void initPages(bool checkScale);
void initPagesWithNewScale();
void displayPage(int page);
void displayNewPage();
void updatePageStatus(int page);
void slotHighlight();
void gotoPage(int page);
void checkPage(int value);
void updateCurrentPage();
void jumpToDest(int page,int left, int top);
void userZoom();
void scaleDocumentZoom(QString zoom);
void fitWidth();
void fitPage();
void zoomIn();
void zoomOut();
void runExternalViewer();

};

#endif

